=======
Credits
=======

Development Lead
----------------

* SekouDiaoNlp <diao.sekou.nlp@gmail.com> GPG key ID: B51D1046EF63C50B

Contributors
------------

* The logo was designed by Zuur_.

.. _Zuur: https://github.com/zuuritaly
